@@ -7,4 +7,4 @@ self.addpkg2db("local", p)
 self.args = "-Q %s" % p.name
 
 self.addrule("PACMAN_RETCODE=0")
-self.addrule("PACMAN_OUTPUT=foobar")
+self.addrule("PACMAN_OUTPUT=%s" % p.name)
