@@ -4,7 +4,7 @@ lp1 = pmpkg("dummy")
 lp1.files = ["bin/dummy"]
 
 lp2 = pmpkg("foobar")
-lp2.files = ["bin/foobar"
+lp2.files = ["bin/foobar",
              "usr/share/file"]
 
 for p in lp1, lp2:
@@ -27,4 +27,5 @@ for p in p1, p2:
 	self.addrule("PKG_EXIST=%s" % p.name)
 self.addrule("FILE_MODIFIED=bin/dummy")
 self.addrule("FILE_MODIFIED=bin/foobar")
+self.addrule("FILE_EXIST=usr/share/file")
 self.addrule("FILE_MODIFIED=usr/share/file")
