@@ -115,8 +115,9 @@ int pacman_add(alpm_list_t *targets)
 	for(i = targets; i; i = alpm_list_next(i)) {
 		char *targ = alpm_list_getdata(i);
 		if(alpm_trans_addtarget(targ) == -1) {
-			fprintf(stderr, _("error: failed to add target '%s' (%s)"), targ,
-			        alpm_strerrorlast());
+			printf(_("failed.\n"));
+			fprintf(stderr, _("error: '%s': %s\n"),
+					targ, alpm_strerrorlast());
 			add_cleanup();
 			return(1);
 		}
@@ -146,7 +147,7 @@ int pacman_add(alpm_list_t *targets)
 			case PM_ERR_CONFLICTING_DEPS:
 				for(i = data; i; i = alpm_list_next(i)) {
 					pmconflict_t *conflict = alpm_list_getdata(i);
-					printf(_(":: %s: conflicts with %s"),
+					printf(_(":: %s: conflicts with %s\n"),
 						alpm_conflict_get_package1(conflict), alpm_conflict_get_package2(conflict));
 				}
 				break;
