@@ -107,9 +107,9 @@ int pacman_remove(alpm_list_t *targets)
 	for(i = finaltargs; i; i = alpm_list_next(i)) {
 		char *targ = alpm_list_getdata(i);
 		if(alpm_trans_addtarget(targ) == -1) {
-			printf("failed.\n");
-			fprintf(stderr, _("error: failed to add target '%s' (%s)\n"), targ,
-			        alpm_strerrorlast());
+			printf(_("failed.\n"));
+			fprintf(stderr, _("error: '%s': %s\n"),
+					targ, alpm_strerrorlast());
 			remove_cleanup();
 			FREELIST(finaltargs);
 			return(1);
