@@ -187,6 +187,34 @@ char *mbasename(const char *path)
 	return (char *)p;
 }
 
+/** Parse the dirname of a program from a path.
+* The path returned should be freed.
+* @param path path to parse dirname from
+*
+* @return everything preceding the final '/'
+*/
+char *mdirname(const char *path)
+{
+	char *ret, *last;
+
+	/* null or empty path */
+	if(path == NULL || path == '\0') {
+		return(strdup("."));
+	}
+
+	ret = strdup(path);
+	last = strrchr(ret, '/');
+
+	if(last != NULL) {
+		/* we found a '/', so terminate our string */
+		*last = '\0';
+		return(ret);
+	}
+	/* no slash found */
+	free(ret);
+	return(strdup("."));
+}
+
 /* output a string, but wrap words properly with a specified indentation
  */
 void indentprint(const char *str, int indent)
@@ -540,7 +568,7 @@ int pm_vasprintf(char **string, pmloglevel_t level, const char *format, va_list
 	/* print a prefix to the message */
 	switch(level) {
 		case PM_LOG_DEBUG:
-			asprintf(string, _("debug: %s"), msg);
+			asprintf(string, "debug: %s", msg);
 			break;
 		case PM_LOG_ERROR:
 			asprintf(string, _("error: %s"), msg);
@@ -587,7 +615,7 @@ int pm_vfprintf(FILE *stream, pmloglevel_t level, const char *format, va_list ar
 	/* print a prefix to the message */
 	switch(level) {
 		case PM_LOG_DEBUG:
-			fprintf(stream, _("debug: "));
+			fprintf(stream, "debug: ");
 			break;
 		case PM_LOG_ERROR:
 			fprintf(stream, _("error: "));
